#!/bin/bash
# Author : Guth (guth@ploposor.com)
# Sources location : http://www.phplogcon.org/Downloads-req-getit-lid-36.phtml

# program name/version
softversion='2.4.0'
softname='phplogcon'

# architecture/package version
arch='noarch'
#cpu='i686'
packageversion='54.2'

# number of parallel tasks of make
#ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/etc/$softname

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
phplogcon: phpLogCon is an easy to use solution for browsing syslog messages
phplogcon: 
phplogcon: phpLogCon is an easy to use solution for browsing syslog messages,
phplogcon: Windows event log data and other network events over the web. While
phplogcon: originally initiated to work in conjunction with Adiscon's
phplogcon: MonitorWare product line, it can easily be modified to work with
phplogcon: other solutions as well.
phplogcon: PhpLogCon enables the system administrator to quickly and easily
phplogcon: review his central log repository. It provides views typically used
phplogcon: on log data. It integrates with web resources for easy analysis of
phplogcon: data found in the logs.
EOF

# extract sources
echo "extracting ..."
srcdir="$softname-$softversion"
srcname="$softname-$softversion"
cd $buildir
rm -rf $srcdir
tar zxf $srcname.tar.gz || exit 0
cd $srcdir || exit 0

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

# configure package for compilation

echo "configuring ..."

# copy the doc files


cp -a \
 * \
 $dest/usr/share/$softname/ || exit 0

(
    cd $dest/usr/doc/$softname-$softversion
    ln -s ../../share/$softname/doc/* .
    ln -s ../../share/$softname/[CcI]* .
) || exit 0

#cp $dest/usr/share/$softname/src/include/config.sample.php $dest/etc/$softname/config.php.new || exit 0
touch $dest/etc/$softname/config.php.new || exit 0
chmod 660 $dest/etc/$softname/config.php.new || exit 0

( cd $dest/usr/share/$softname/src/
    ln -s ../../../../etc/$softname/config.php  config.php
) || exit 0

# put the ZenWalk build and other needed files in the right directory
echo "setting perms ..."
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion/ || exit 0
chown -R root.root $dest/usr/src/$softname-$softversion || exit 0

# make the package and move it to the build directory

# create doinst.sh file
echo "config() {
  NEW=\"\$1.new\"
  OLD=\"\$1\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then
    # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}

if grep -q daemon /etc/passwd; then
   chown daemon etc/phplogcon/config.php.new
fi

config etc/phplogcon/config.php

(
docroot=\"\$(grep -E '^[[:space:]]*DocumentRoot' etc/apache/httpd.conf \
| sed -r 's@^[[:space:]]*DocumentRoot[[:space:]]*\"/?(.*)\"@\\1@g')\"

cd \$docroot || exit 1

if ! [ -a $softname ]; then
   ln -s /usr/share/$softname/src $softname
fi
)

" > $dest/install/doinst.sh

chmod 755 $dest/install/doinst.sh || exit 0



#------------------( Create The *.dep File )
echo "creating .dep ..."
echo -n "apache2,php" > $buildir/$package.dep

cd $dest
/sbin/makepkg -l y -c n $package.tgz || exit 0
mv $package.tgz $buildir

# computes the md5sum signature for the package
echo "creating .md5 ..."
cd $buildir
md5sum $package.tgz > $package.md5

if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi

echo -n "$(grep '#*Sou[r]ce' $0 |cut -f5- -d ' ')" > $package.src
